cmd

package
v0.111.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 2, 2026 License: MIT Imports: 31 Imported by: 0

Documentation

Overview

Package cmd contains all cobra subcommands for the nn CLI.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewRootCmd

func NewRootCmd(cfgFile string) *cobra.Command

NewRootCmd creates a fresh root command. cfgFile overrides the default config path.

func NewRootCmdForTest

func NewRootCmdForTest(cfgFile string) *cobra.Command

NewRootCmdForTest creates a root command wired to the given config file path. Exported for use in tests within the cmd_test package.

Types

This section is empty.

Jump to