Documentation
¶
Overview ¶
Package cmd contains all cobra subcommands for the nn CLI.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewRootCmd ¶
NewRootCmd creates a fresh root command. cfgFile overrides the default config path.
func NewRootCmdForTest ¶
NewRootCmdForTest creates a root command wired to the given config file path. Exported for use in tests within the cmd_test package.
Types ¶
This section is empty.
Source Files
¶
- ast.go
- atomicity.go
- backlinks.go
- bulk_link.go
- bulk_new.go
- bulk_update_link.go
- capture.go
- clusters.go
- delete.go
- depth.go
- editor.go
- gap.go
- graph.go
- graph_embed.go
- guide.go
- index_cmd.go
- init.go
- install.go
- install_hooks.go
- install_skills.go
- link.go
- links.go
- list.go
- log.go
- new.go
- path.go
- promote.go
- random.go
- remind.go
- review.go
- root.go
- search.go
- show.go
- status.go
- suggest_links.go
- suggest_tags.go
- suggestions.go
- tags.go
- update.go
- update_link.go
Click to show internal directories.
Click to hide internal directories.