Documentation
¶
Overview ¶
Package config handles loading and resolving nn configuration.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DefaultConfigPath ¶
func DefaultConfigPath() string
DefaultConfigPath returns the default path to the nn config file. Respects NN_CONFIG_DIR environment variable for testability.
Types ¶
type Config ¶
type Config struct {
// contains filtered or unexported fields
}
Config holds the full parsed configuration.
type NotebookEntry ¶
NotebookEntry holds the configuration for a single named notebook.
Click to show internal directories.
Click to hide internal directories.