Documentation
¶
Overview ¶
Package index manages the SQLite cache of note metadata. The index is derived from the Markdown files and can be fully rebuilt at any time.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Index ¶
type Index struct {
// contains filtered or unexported fields
}
Index wraps an open SQLite database.
func (*Index) CountLinks ¶
CountLinks returns the number of rows in the links table.
func (*Index) CountNotes ¶
CountNotes returns the number of rows in the notes table.
func (*Index) IsStale ¶
IsStale returns true if the file at path has changed since it was indexed. Stale detection uses content hash (sha256) of the file.
func (*Index) Rebuild ¶
Rebuild clears the index and repopulates it by scanning all .md files in dir.
func (*Index) TableExists ¶
TableExists returns nil if the named table exists, or an error otherwise.
Click to show internal directories.
Click to hide internal directories.